@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '0.10';
+our $VERSION = '1.00';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -19,7 +19,9 @@ use XML::LibXML;
 sub new {
 	my ( $class, %opt ) = @_;
 
-	my $ua = LWP::UserAgent->new(%opt);
+	my %lwp_options = %{ $opt{lwp_options} // { timeout => 10 } };
+
+	my $ua = LWP::UserAgent->new( %{ $opt{lwp_options} } );
 
 	if ( not $opt{station} ) {
 		confess('station flag must be passed');
@@ -70,7 +72,7 @@ sub new {
 
 	# tra (transfer?) indicates a train changing its ID, so there are two
 	# results for the same train. Remove the departure-only trains from the
-	# result set and merge them with their arrival-only counterpairt.
+	# result set and merge them with their arrival-only counterpart.
 	# This way, in case the arrival is available but the departure isn't,
 	# nothing gets lost.
 	my @merge_candidates
@@ -222,7 +224,6 @@ sub get_realtime {
 
 	for my $s ( $xml->findnodes('/timetable/s') ) {
 		my $id     = $s->getAttribute('id');
-		my $e_tl   = ( $s->findnodes('./tl') )[0];
 		my $e_ar   = ( $s->findnodes('./ar') )[0];
 		my $e_dp   = ( $s->findnodes('./dp') )[0];
 		my @e_refs = $s->findnodes('./ref/tl');
@@ -261,16 +262,11 @@ sub get_realtime {
 
 		$result->set_messages(%messages);
 
-		if ($e_tl) {
-			$result->set_tl(
-				class     => $e_tl->getAttribute('f'),    # D N S F
-				unknown_t => $e_tl->getAttribute('t'),    # p
-				train_no  => $e_tl->getAttribute('n'),    # dep number
-				type      => $e_tl->getAttribute('c'),    # S/ICE/ERB/...
-				line_no   => $e_tl->getAttribute('l'),    # 1 -> S1, ...
-				unknown_o => $e_tl->getAttribute('o'),    # owner: 03/80/R2/...
-			);
-		}
+		# note: A departure may also have a ./tl attribute. However, we do
+		# not need to process it because it only matters for departures which
+		# are not planned (or not in the plans we requested). However, in
+		# those cases we already called add_result earlier, which reads ./tl
+		# by itself.
 		for my $e_ref (@e_refs) {
 			$result->add_raw_ref(
 				class     => $e_ref->getAttribute('f'),    # D N S F
@@ -406,7 +402,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 0.10
+version 1.00
 
 =head1 DESCRIPTION
 
@@ -418,7 +414,7 @@ L<https://iris.noncd.db.de/wbt/js/index.html?typ=ab&style=qrab&bhf=EE&SecLang=&Z
 
 =over
 
-=item my $states = Travel::Status::DE::IRIS->new(I<%opt>)
+=item my $status = Travel::Status::DE::IRIS->new(I<%opt>)
 
 Requests schedule and realtime data for a specific station at a specific
 point in time. Returns a new Travel::Status::DE::IRIS object.
@@ -448,6 +444,11 @@ have no effect. However, as the IRIS occasionally contains unscheduled
 departures or qos messages known far in advance (e.g. 12 hours from now), any
 non-negative integer is accepted.
 
+=item B<lwp_options> => I<\%hashref>
+
+Passed on to C<< LWP::UserAgent->new >>. Defaults to C<< { timeout => 10 } >>,
+you can use an empty hashref to override it.
+
 =item B<station> => I<stationcode>
 
 Mandatory: Which station to return departures for. Note that this is not a
@@ -457,8 +458,6 @@ name to code mapping.
 
 =back
 
-All other options are passed to the LWP::UserAgent(3pm) constructor.
-
 =item $status->errstr
 
 In case of a fatal HTTP request or IRIS error, returns a string describing it.
