@@ -15,7 +15,7 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '0.10';
+our $VERSION = '1.00';
 
 my %translation = (
 	2  => 'Polizeiliche Ermittlung',
@@ -317,14 +317,6 @@ sub add_raw_ref {
 	return $self;
 }
 
-sub set_tl {
-	my ( $self, %attrib ) = @_;
-
-	# TODO
-
-	return $self;
-}
-
 sub set_unscheduled {
 	my ( $self, $unscheduled ) = @_;
 
@@ -732,7 +724,7 @@ sub TO_JSON {
 	delete $copy{replaced_by};
 	delete $copy{replacement_for};
 
-	return { %copy };
+	return {%copy};
 }
 
 1;
@@ -758,7 +750,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 0.10
+version 1.00
 
 =head1 DESCRIPTION
 
